@@ -14,7 +14,7 @@ imp2 <- mice(nhanes[14:25, ], m = 2, maxit = 1, print = FALSE)
 imp3 <- mice(nhanes2, m = 2, maxit = 1, print = FALSE)
 imp4 <- mice(nhanes2, m = 1, maxit = 1, print = FALSE)
 expect_warning(imp5 <<- mice(nhanes[1:13, ], m = 2, maxit = 2, print = FALSE))
-expect_error(imp6 <<- mice(nhanes[1:13, 2:3], m = 2, maxit = 2, print = FALSE), "nothing left to impute")
+expect_error(imp6 <<- mice(nhanes[1:13, 2:3], m = 2, maxit = 2, print = FALSE), "`mice` detected constant and/or collinear variables. No predictors were left after their removal.")
 nh3 <- nhanes
 colnames(nh3) <- c("AGE", "bmi", "hyp", "chl")
 imp7 <- mice(nh3[14:25, ], m = 2, maxit = 2, print = FALSE)
@@ -66,7 +66,7 @@ set.seed <- 818
 x <- rnorm(10)
 D <- data.frame(x=x, y=2*x+rnorm(10))
 D[c(2:4, 7), 1] <- NA
-expect_error(D_mids <<- mice(D[1:5,], print = FALSE), "nothing left to impute")
+expect_error(D_mids <<- mice(D[1:5,], print = FALSE), "`mice` detected constant and/or collinear variables. No predictors were left after their removal.")
 expect_warning(D_mids <<- mice(D[1:5,], print = FALSE, remove.collinear = FALSE))
 
 D_rbind <- mice:::rbind.mids(D_mids, D[6:10,])
